==> haskell-zip-archive-0.4.3.2-8-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-zip-archive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 zip-archive
version:              0.4.3.2
visibility:           public
id:                   zip-archive-0.4.3.2-JoEJDrgiwOE77pKRvuA2GN
key:                  zip-archive-0.4.3.2-JoEJDrgiwOE77pKRvuA2GN
license:              BSD-3-Clause
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             http://github.com/jgm/zip-archive
synopsis:             Library for creating and modifying zip archives.
description:
    The zip-archive library provides functions for creating, modifying, and
    extracting files from zip archives. The zip archive format is
    documented in <http://www.pkware.com/documents/casestudies/APPNOTE.TXT>.

    Certain simplifying assumptions are made about the zip archives: in
    particular, there is no support for strong encryption, zip files that
    span multiple disks, ZIP64, OS-specific file attributes, or compression
    methods other than Deflate. However, the library should be able to read
    the most common zip archives, and the archives it produces should be
    readable by all standard unzip programs.

    Archives are built and extracted in memory, so manipulating large zip
    files will consume a lot of memory. If you work with large zip files or
    need features not supported by this library, a better choice may be
    <http://hackage.haskell.org/package/zip zip>, which uses a
    memory-efficient streaming approach. However, zip can only read and
    write archives inside instances of MonadIO, so zip-archive is a better
    choice if you want to manipulate zip archives in "pure" contexts.

    As an example of the use of the library, a standalone zip archiver and
    extracter is provided in the source distribution.

category:             Codec
abi:                  d1fe38863bcfaa07e9f1fa32954c491b
exposed:              True
exposed-modules:      Codec.Archive.Zip
import-dirs:          /usr/lib/ghc-9.2.8/site-local/zip-archive-0.4.3.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/zip-archive-0.4.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-zip-archive
hs-libraries:         HSzip-archive-0.4.3.2-JoEJDrgiwOE77pKRvuA2GN
depends:
    array-0.5.4.0 base-4.16.4.0 binary-0.8.9.0 bytestring-0.11.4.0
    containers-0.6.5.1 digest-0.0.1.7-AeS2LdKLvsU2P2B09AiIin
    directory-1.3.6.2 filepath-1.4.2.2 mtl-2.2.2 pretty-1.1.3.6
    text-1.2.5.0 time-1.11.1.1 unix-2.7.2.2
    zlib-0.6.3.0-3hvuMBy4V96vMim3ALKcj

haddock-interfaces:   /usr/share/doc/haskell-zip-archive/html/zip-archive.haddock
haddock-html:         /usr/share/doc/haskell-zip-archive/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-zip-archive-0.4.3.2-9-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-zip-archive.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 zip-archive
version:              0.4.3.2
visibility:           public
id:                   zip-archive-0.4.3.2-EmgEzeUTEeoDEwagGcLeUb
key:                  zip-archive-0.4.3.2-EmgEzeUTEeoDEwagGcLeUb
license:              BSD-3-Clause
maintainer:           jgm@berkeley.edu
author:               John MacFarlane
homepage:             http://github.com/jgm/zip-archive
synopsis:             Library for creating and modifying zip archives.
description:
    The zip-archive library provides functions for creating, modifying, and
    extracting files from zip archives. The zip archive format is
    documented in <http://www.pkware.com/documents/casestudies/APPNOTE.TXT>.

    Certain simplifying assumptions are made about the zip archives: in
    particular, there is no support for strong encryption, zip files that
    span multiple disks, ZIP64, OS-specific file attributes, or compression
    methods other than Deflate. However, the library should be able to read
    the most common zip archives, and the archives it produces should be
    readable by all standard unzip programs.

    Archives are built and extracted in memory, so manipulating large zip
    files will consume a lot of memory. If you work with large zip files or
    need features not supported by this library, a better choice may be
    <http://hackage.haskell.org/package/zip zip>, which uses a
    memory-efficient streaming approach. However, zip can only read and
    write archives inside instances of MonadIO, so zip-archive is a better
    choice if you want to manipulate zip archives in "pure" contexts.

    As an example of the use of the library, a standalone zip archiver and
    extracter is provided in the source distribution.

category:             Codec
abi:                  f4744bc55c408cca0b2125f311c479f0
exposed:              True
exposed-modules:      Codec.Archive.Zip
import-dirs:          /usr/lib/ghc-9.2.8/site-local/zip-archive-0.4.3.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/zip-archive-0.4.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-zip-archive
hs-libraries:         HSzip-archive-0.4.3.2-EmgEzeUTEeoDEwagGcLeUb
depends:
    array-0.5.4.0 base-4.16.4.0 binary-0.8.9.0 bytestring-0.11.4.0
    containers-0.6.5.1 digest-0.0.1.7-AeS2LdKLvsU2P2B09AiIin
    directory-1.3.6.2 filepath-1.4.2.2 mtl-2.2.2 pretty-1.1.3.6
    text-1.2.5.0 time-1.11.1.1 unix-2.7.2.2
    zlib-0.6.3.0-Cwi1aHM7gq5Lji6PVFmfhp

haddock-interfaces:   /usr/share/doc/haskell-zip-archive/html/zip-archive.haddock
haddock-html:         /usr/share/doc/haskell-zip-archive/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
